class Deis::Client::Mock
  include Deis::Client::Shared

  attr_reader :username, :url, :password, :token

  def self.data
    @data ||= Hash.new { |h, url|
      h[url] = {
        :users => {},
      }
    }
  end

  def self.reset!
    @data = nil
  end

  def self.serial_id
    @current_id ||= 0
    @current_id += 1
    @current_id.to_s
  end

  def data
    self.class.data[@url]
  end

  def serial_id
    self.class.serial_id
  end

  def initialize(options={})
    @url                 = options[:url]
    @username, @password = options[:username], options[:password]
    @auth_token          = options[:token]
  end

  def response(options={})
    method = options[:method] || :get
    status = options[:status] || 200
    path   = options[:path]
    body   = options[:body]
    url    = options[:url] || File.join(@url, "api/v1", path)

    request_headers  = {
      "Accept"       => "application/json",
      "Content-Type" => "application/json",
    }

    response_headers = {
      "Content-Type"            => "application/json",
      "x_deis_api_version"      => "1.1",
      "x_deis_platform_version" => "1.2.2",
    }

    # request phase
    # * :method - :get, :post, ...
    # * :url    - URI for the current request; also contains GET parameters
    # * :body   - POST parameters for :post/:put requests
    # * :request_headers

    # response phase
    # * :status - HTTP response status code, such as 200
    # * :body   - the response body
    # * :response_headers

    env = Faraday::Env.from(
      :method           => method,
      :url              => URI.parse(url),
      :body             => body,
      :request_headers  => request_headers,
      :response_headers => response_headers,
      :status           => status,
    )

    Faraday::Response::RaiseError.new.on_complete(env) ||
      Faraday::Response.new(env)
  end
end
