class Deis::Client::Real

  include Deis::Client::Shared

  attr_accessor :username, :url, :logger

  def initialize(options={})
    @url      = options.fetch(:url)
    @logger   = options[:logger]   || Logger.new(nil)
    adapter   = options[:adapter]  || Faraday.default_adapter
    @username = options[:username]
    password  = options[:password]
    token     = options[:token]


    @auth_token = password || token

    connection_options = options[:connection_options] || {}

    @connection = Faraday.new({url: @url}.merge(connection_options)) do |builder|
      # response
      if username && auth_token
        builder.use Faraday::Request::BasicAuthentication, @username, @auth_token
      end

      builder.use Faraday::Response::RaiseError
      builder.request :retry,
        :max            => 5,
        :interval       => 1,
        :backoff_factor => 2
      builder.response :json

      # request
      builder.request :multipart
      builder.request :json

      builder.use Ey::Logger::Faraday, format: :machine, device: @logger, prefix: "deis"
      builder.adapter adapter
    end
  end

  def request(options={})
    method  = options[:method] || :get
    url     = options[:url] || File.join(@url, "v1", options.fetch(:path))
    params  = options[:params] || {}
    body    = options[:body]
    headers = {
      "Content-Type" => "application/json",
      "Accept"       => "application/json",
    }.merge(options[:headers] || {})

    @connection.send(method) do |req|
      req.url(url)
      req.headers.merge!(headers)
      req.params.merge!(params)
      req.body = body
    end
  end
end
