class Deis::Client::Real
  # @see http://docs.deis.io/en/v1.3.0/reference/api-v1.0/#register-a-new-user
  def register_user(params={})
    request(
      :path   => "auth/register",
      :method => :post,
      :body   => Cistern::Hash.slice(params, "username", "password", "email", "first_name", "last_name"),
    )
  end
end

class Deis::Client::Mock
  def register_user(params={})
    id = self.serial_id

    unless params["username"]
      response(
        :body   => {"username" => "This field is required."},
        :status => 400,
      )
    end

    unless params["password"]
      response(
        :body   => {"password" => "This field is required."},
        :status => 400,
      )
    end

    user_params = Cistern::Hash.slice(params, "username", "password", "email", "first_name", "last_name").merge(
      "id"               => id,
      "is_active"        => true,
      "is_staff"         => false,
      "groups"           => [],
      "user_permissions" => [],
      "is_superuser"     => false,
    )

    if self.data[:users].keys.empty?
      user_params.merge!("is_staff" => true, "is_superuser" => true)
    end

    if self.data[:users].values.find { |u| u["username"] == user_params["username"] }
      response(
        :body   => {"username" => "User with this Username already exists."},
        :status => 400,
      )
    end

    self.data[:users][id] = user_params

    response(
      :path   => "/auth/register",
      :method => :post,
      :body   => user_params,
      :status => 201,
    )
  end
end
